@@ -70,15 +70,6 @@ class WordpressFeedAdapter(BaseFeedAdapter):
         feed.entries = feed.entries[:n_items]
 
         for entry in feed.entries:
-            n_comments = int(entry.get('slash_comments', 0))
-
-            if n_comments:
-                response = FeedItemResponses(n_comments,
-                                             entry.comments,
-                                             'comment')
-            else:
-                response=None
-
             title = entry.title
             if not title.strip():
                 title = unescape(entry.summary) # XXX unescaping seems weird
@@ -88,13 +79,31 @@ class WordpressFeedAdapter(BaseFeedAdapter):
             # and since we're using the "internal" link this will
             # be wrong. so i'll just manually replace each item's
             # 'base href' with the right one.
+            #
+            # we have to do this for the link to the entry itself and also
+            # the link to the entry's comments/replies, if it exists
             if entry.link.startswith(base_uri):
                 entry.link = entry.link[len(base_uri):] # lstrip base_uri
                 entry.link = '/'.join((self.link.rstrip('/'), entry.link.lstrip('/')))
+
+            num_comments = int(entry.get('slash_comments', 0))
+
+            if num_comments > 0:
+                if entry.comments.startswith(base_uri): # see #2845
+                    entry.comments = entry.comments[len(base_uri):]
+                    entry.comments = '/'.join((self.link.rstrip('/'), 
+                                               entry.comments.lstrip('/')))
+                response = FeedItemResponses(num_comments,
+                                             entry.comments,
+                                             'comment')
+            else:
+                response = None
+
             self.add_item(title=title,
                           description=entry.summary,
                           link=entry.link,
                           author=entry.author,
+                          authorURL=self.memberURL(entry.userid),
                           pubDate=entry.date,
                           responses=response)
 
